==> lxqt-l10n-0.12.0.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-mainmenu/mainmenu_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>メインメニューを表示/隠す</translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">終了</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>メインメニューの設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>ボタンの文字列:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>フォントサイズの指定:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> ポイント</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>メニューファイル</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>メニューファイル:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>キーボードショートカット</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>ショートカットを記録するにはボタンをクリック:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>メニューファイルを選択</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>メニューファイル(*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-mainmenu/mainmenu_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>メインメニューを表示/隠す</translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">終了</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>メインメニューの設定</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>ボタンの文字列:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>フォントサイズの指定:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> ポイント</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>メニューファイル</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>メニューファイル:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation>最大のアイテムの幅:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>検索中はメニューエントリーを隠す</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>メニューの表示時は検索フォームをクリアする</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>キーボードショートカット</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>ショートカットを記録するにはボタンをクリック:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>リセット</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation>アイコンファイルの選択</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation>画像 (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>メニューファイルを選択</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>メニューファイル(*.menu)</translation>
    </message>
</context>
</TS>
